@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -681,6 +681,11 @@ def cleanup_stylesheets_walker(arguments, directory_name, names):
     windows_newline, fix_extra_newlines, property_order,\
     rules_skip, file_extensions, file_exclusion = arguments
 
+    # tries to run the handle ignore operation for the current set of names and
+    # in case there's a processing returns the control flow immediately as no
+    # more handling is meant to occur for the current operation (ignored)
+    if extra.handle_ignore(names): return
+
     # removes the complete set of names that are meant to be excluded from the
     # current set names to be visit (avoid visiting them)
     for exclusion in file_exclusion:
