@@ -2,22 +2,22 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
 # Hive Administration Scripts is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the Apache License as published by the Apache
+# Foundation, either version 2.0 of the License, or (at your option) any
+# later version.
 #
 # Hive Administration Scripts is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# Apache License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with Hive Administration Scripts. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the Apache License along with
+# Hive Administration Scripts. If not, see <http://www.apache.org/licenses/>.
 
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
@@ -31,10 +31,10 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
-__license__ = "GNU General Public License (GPL), Version 3"
+__license__ = "Apache License, Version 2.0"
 """ The license for the module """
 
 configurations = (
@@ -85,7 +85,8 @@ configurations = (
             "rst",
             "liquid",
             "go",
-            "gitignore"
+            "gitignore",
+            "swift"
         ),
         "file_exclusion" : ("android-sdk",)
     },
@@ -99,7 +100,8 @@ configurations = (
             "drg",
             "am",
             "m4",
-            "md"
+            "md",
+            "csv"
         ),
         "file_exclusion" : ("android-sdk",)
     }
